# nclpy


[![image](https://img.shields.io/pypi/v/nclpy.svg)](https://pypi.python.org/pypi/nclpy)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![image](https://img.shields.io/conda/vn/conda-forge/nclpy.svg)](https://anaconda.org/conda-forge/nclpy)



**A Python package for working with NCL**


-   Free software: MIT license
-   Documentation: https://HJRubin.github.io/nclpy
    
## Installation

### Conda

``` 
conda install nclpy -c conda-forge
```
## Features

-   Allows you to reproduce NCL-style graphics with Python commands
-   Not really sure if this is feasible but it would be nice

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
